==> physx-jni-0.3.2-sources.jar: physx/vehicle/PxEngineTorqueLookupTable.java <==
package physx.vehicle;

import physx.NativeObject;

public class PxEngineTorqueLookupTable extends NativeObject {

    public static PxEngineTorqueLookupTable wrapPointer(long address) {
        return new PxEngineTorqueLookupTable(address);
    }
    
    protected PxEngineTorqueLookupTable(long address) {
        super(address);
    }

    // Constructors

    public PxEngineTorqueLookupTable() {
        address = _PxEngineTorqueLookupTable();
    }
    private static native long _PxEngineTorqueLookupTable();

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isStackAllocated) {
            throw new IllegalStateException(this + " is stack allocated and cannot be deleted");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @param index Array index
     * @return float
     */
    public float getMDataPairs(int index) {
        return _getMDataPairs(address, index);
    }
    private static native float _getMDataPairs(long address, int index);

    /**
     * @param index Array index
     * @param value float
     */
    public void setMDataPairs(int index, float value) {
        _setMDataPairs(address, index, value);
    }
    private static native void _setMDataPairs(long address, int index, float value);

    /**
     * @return unsigned long
     */
    public int getMNbDataPairs() {
        return _getMNbDataPairs(address);
    }
    private static native int _getMNbDataPairs(long address);

    /**
     * @param value unsigned long
     */
    public void setMNbDataPairs(int value) {
        _setMNbDataPairs(address, value);
    }
    private static native void _setMNbDataPairs(long address, int value);

    // Functions

    /**
     * @param x float
     * @param y float
     */
    public void addPair(float x, float y) {
        _addPair(address, x, y);
    }
    private static native void _addPair(long address, float x, float y);

    /**
     * @param x float
     * @return float
     */
    public float getYVal(float x) {
        return _getYVal(address, x);
    }
    private static native float _getYVal(long address, float x);

    /**
     * @return unsigned long
     */
    public int getNbDataPairs() {
        return _getNbDataPairs(address);
    }
    private static native int _getNbDataPairs(long address);

    public void clear() {
        _clear(address);
    }
    private static native void _clear(long address);

    /**
     * @param i unsigned long
     * @return float
     */
    public float getX(int i) {
        return _getX(address, i);
    }
    private static native float _getX(long address, int i);

    /**
     * @param i unsigned long
     * @return float
     */
    public float getY(int i) {
        return _getY(address, i);
    }
    private static native float _getY(long address, int i);

}

==> physx-jni-0.4.0-sources.jar: physx/vehicle/PxEngineTorqueLookupTable.java <==
package physx.vehicle;

import physx.NativeObject;

public class PxEngineTorqueLookupTable extends NativeObject {

    public static PxEngineTorqueLookupTable wrapPointer(long address) {
        return new PxEngineTorqueLookupTable(address);
    }
    
    protected PxEngineTorqueLookupTable(long address) {
        super(address);
    }

    // Constructors

    public PxEngineTorqueLookupTable() {
        address = _PxEngineTorqueLookupTable();
    }
    private static native long _PxEngineTorqueLookupTable();

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @param index Array index
     * @return WebIDL type: float
     */
    public float getMDataPairs(int index) {
        return _getMDataPairs(address, index);
    }
    private static native float _getMDataPairs(long address, int index);

    /**
     * @param index Array index
     * @param value WebIDL type: float
     */
    public void setMDataPairs(int index, float value) {
        _setMDataPairs(address, index, value);
    }
    private static native void _setMDataPairs(long address, int index, float value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getMNbDataPairs() {
        return _getMNbDataPairs(address);
    }
    private static native int _getMNbDataPairs(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setMNbDataPairs(int value) {
        _setMNbDataPairs(address, value);
    }
    private static native void _setMNbDataPairs(long address, int value);

    // Functions

    /**
     * @param x WebIDL type: float
     * @param y WebIDL type: float
     */
    public void addPair(float x, float y) {
        _addPair(address, x, y);
    }
    private static native void _addPair(long address, float x, float y);

    /**
     * @param x WebIDL type: float
     * @return WebIDL type: float
     */
    public float getYVal(float x) {
        return _getYVal(address, x);
    }
    private static native float _getYVal(long address, float x);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbDataPairs() {
        return _getNbDataPairs(address);
    }
    private static native int _getNbDataPairs(long address);

    public void clear() {
        _clear(address);
    }
    private static native void _clear(long address);

    /**
     * @param i WebIDL type: unsigned long
     * @return WebIDL type: float
     */
    public float getX(int i) {
        return _getX(address, i);
    }
    private static native float _getX(long address, int i);

    /**
     * @param i WebIDL type: unsigned long
     * @return WebIDL type: float
     */
    public float getY(int i) {
        return _getY(address, i);
    }
    private static native float _getY(long address, int i);

}
